/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qcombobox.sip"
#include <qcombobox.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 509 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 482 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 253 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 363 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 205 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 471 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 460 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 398 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 425 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 384 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 834 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qcompleter.sip"
#include <qcompleter.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 87 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 90 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 93 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 96 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 99 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 102 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 105 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qlineedit.sip"
#include <qlineedit.h>
#line 108 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 114 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 117 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 120 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 123 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 126 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 129 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 132 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 135 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 138 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 141 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 144 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 147 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 150 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 153 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 156 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 159 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 162 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 165 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 168 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 171 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 174 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 570 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 177 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 619 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 180 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 592 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 183 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 608 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 186 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 675 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 189 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 302 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 192 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 438 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 412 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 198 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 52 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 201 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 204 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 207 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 210 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 213 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 216 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 219 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 222 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 225 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 228 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 231 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 236 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 239 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 242 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 245 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 248 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 251 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 254 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 257 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 260 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 263 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 266 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 269 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"


class sipQComboBox : public ::QComboBox
{
public:
    sipQComboBox(::QWidget*);
    virtual ~sipQComboBox();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void hidePopup() SIP_OVERRIDE;
    void showPopup() SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQComboBox(const sipQComboBox &);
    sipQComboBox &operator = (const sipQComboBox &);

    char sipPyMethods[48];
};

sipQComboBox::sipQComboBox(::QWidget*a0): ::QComboBox(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQComboBox::~sipQComboBox()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQComboBox::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QComboBox);

    return ::QComboBox::metaObject();
}

int sipQComboBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QComboBox::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QComboBox, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQComboBox::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QComboBox, _clname, &sipCpp) ? sipCpp : ::QComboBox::qt_metacast(_clname));
}

void sipQComboBox::hidePopup()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_hidePopup);

    if (!sipMeth)
    {
        ::QComboBox::hidePopup();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQComboBox::showPopup()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_showPopup);

    if (!sipMeth)
    {
        ::QComboBox::showPopup();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQComboBox::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QComboBox::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QComboBox::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QComboBox::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QComboBox::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QComboBox::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQComboBox::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QComboBox::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQComboBox::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QComboBox::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQComboBox::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QComboBox::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQComboBox::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QComboBox::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQComboBox::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QComboBox::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQComboBox::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QComboBox::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQComboBox::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QComboBox::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQComboBox::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QComboBox::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQComboBox::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QComboBox::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QComboBox::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QComboBox::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QComboBox::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QComboBox::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QComboBox::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QComboBox::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QComboBox::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QComboBox::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QComboBox::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QComboBox::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QComboBox::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QComboBox::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QComboBox::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QComboBox::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QComboBox::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QComboBox::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QComboBox::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QComboBox::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QComboBox::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QComboBox::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QComboBox::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QComboBox::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QComboBox::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QComboBox::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QComboBox::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQComboBox::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QComboBox::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQComboBox::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QComboBox::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQComboBox::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QComboBox::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQComboBox::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QComboBox::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQComboBox::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QComboBox::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQComboBox::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QComboBox::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQComboBox::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[47]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QComboBox::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QComboBox_maxVisibleItems, "maxVisibleItems(self) -> int");

extern "C" {static PyObject *meth_QComboBox_maxVisibleItems(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_maxVisibleItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxVisibleItems();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_maxVisibleItems, doc_QComboBox_maxVisibleItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setMaxVisibleItems, "setMaxVisibleItems(self, maxItems: int)");

extern "C" {static PyObject *meth_QComboBox_setMaxVisibleItems(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setMaxVisibleItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setMaxVisibleItems(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setMaxVisibleItems, doc_QComboBox_setMaxVisibleItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_count, "count(self) -> int");

extern "C" {static PyObject *meth_QComboBox_count(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_count, doc_QComboBox_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setMaxCount, "setMaxCount(self, max: int)");

extern "C" {static PyObject *meth_QComboBox_setMaxCount(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setMaxCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setMaxCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setMaxCount, doc_QComboBox_setMaxCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_maxCount, "maxCount(self) -> int");

extern "C" {static PyObject *meth_QComboBox_maxCount(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_maxCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_maxCount, doc_QComboBox_maxCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_duplicatesEnabled, "duplicatesEnabled(self) -> bool");

extern "C" {static PyObject *meth_QComboBox_duplicatesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_duplicatesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->duplicatesEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_duplicatesEnabled, doc_QComboBox_duplicatesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setDuplicatesEnabled, "setDuplicatesEnabled(self, enable: bool)");

extern "C" {static PyObject *meth_QComboBox_setDuplicatesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setDuplicatesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setDuplicatesEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setDuplicatesEnabled, doc_QComboBox_setDuplicatesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setFrame, "setFrame(self, a0: bool)");

extern "C" {static PyObject *meth_QComboBox_setFrame(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setFrame(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setFrame, doc_QComboBox_setFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_hasFrame, "hasFrame(self) -> bool");

extern "C" {static PyObject *meth_QComboBox_hasFrame(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_hasFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasFrame();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_hasFrame, doc_QComboBox_hasFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_findText, "findText(self, text: Optional[str], flags: Union[Qt.MatchFlags, Qt.MatchFlag] = Qt.MatchExactly|Qt.MatchCaseSensitive) -> int");

extern "C" {static PyObject *meth_QComboBox_findText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_findText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt::MatchFlags a1def = Qt::MatchExactly|Qt::MatchCaseSensitive;
        ::Qt::MatchFlags* a1 = &a1def;
        int a1State = 0;
        const ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QString, &a0, &a0State, sipType_Qt_MatchFlags, &a1, &a1State))
        {
            int sipRes;

            sipRes = sipCpp->findText(*a0, *a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_Qt_MatchFlags, a1State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_findText, doc_QComboBox_findText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_findData, "findData(self, data: Any, role: int = Qt.UserRole, flags: Union[Qt.MatchFlags, Qt.MatchFlag] = Qt.MatchExactly|Qt.MatchCaseSensitive) -> int");

extern "C" {static PyObject *meth_QComboBox_findData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_findData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        int a1 = Qt::UserRole;
        ::Qt::MatchFlags a2def = Qt::MatchExactly|Qt::MatchCaseSensitive;
        ::Qt::MatchFlags* a2 = &a2def;
        int a2State = 0;
        const ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|iJ1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QVariant, &a0, &a0State, &a1, sipType_Qt_MatchFlags, &a2, &a2State))
        {
            int sipRes;

            sipRes = sipCpp->findData(*a0, a1, *a2);
            sipReleaseType(const_cast<::QVariant *>(a0), sipType_QVariant, a0State);
            sipReleaseType(a2, sipType_Qt_MatchFlags, a2State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_findData, doc_QComboBox_findData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_insertPolicy, "insertPolicy(self) -> QComboBox.InsertPolicy");

extern "C" {static PyObject *meth_QComboBox_insertPolicy(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_insertPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QComboBox::InsertPolicy sipRes;

            sipRes = sipCpp->insertPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QComboBox_InsertPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_insertPolicy, doc_QComboBox_insertPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setInsertPolicy, "setInsertPolicy(self, policy: QComboBox.InsertPolicy)");

extern "C" {static PyObject *meth_QComboBox_setInsertPolicy(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setInsertPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QComboBox::InsertPolicy a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QComboBox_InsertPolicy, &a0))
        {
            sipCpp->setInsertPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setInsertPolicy, doc_QComboBox_setInsertPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_sizeAdjustPolicy, "sizeAdjustPolicy(self) -> QComboBox.SizeAdjustPolicy");

extern "C" {static PyObject *meth_QComboBox_sizeAdjustPolicy(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_sizeAdjustPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QComboBox::SizeAdjustPolicy sipRes;

            sipRes = sipCpp->sizeAdjustPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QComboBox_SizeAdjustPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_sizeAdjustPolicy, doc_QComboBox_sizeAdjustPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setSizeAdjustPolicy, "setSizeAdjustPolicy(self, policy: QComboBox.SizeAdjustPolicy)");

extern "C" {static PyObject *meth_QComboBox_setSizeAdjustPolicy(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setSizeAdjustPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QComboBox::SizeAdjustPolicy a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QComboBox_SizeAdjustPolicy, &a0))
        {
            sipCpp->setSizeAdjustPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setSizeAdjustPolicy, doc_QComboBox_setSizeAdjustPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_minimumContentsLength, "minimumContentsLength(self) -> int");

extern "C" {static PyObject *meth_QComboBox_minimumContentsLength(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_minimumContentsLength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimumContentsLength();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_minimumContentsLength, doc_QComboBox_minimumContentsLength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setMinimumContentsLength, "setMinimumContentsLength(self, characters: int)");

extern "C" {static PyObject *meth_QComboBox_setMinimumContentsLength(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setMinimumContentsLength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setMinimumContentsLength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setMinimumContentsLength, doc_QComboBox_setMinimumContentsLength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_iconSize, "iconSize(self) -> QSize");

extern "C" {static PyObject *meth_QComboBox_iconSize(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_iconSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->iconSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_iconSize, doc_QComboBox_iconSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setIconSize, "setIconSize(self, size: QSize)");

extern "C" {static PyObject *meth_QComboBox_setIconSize(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setIconSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setIconSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setIconSize, doc_QComboBox_setIconSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_isEditable, "isEditable(self) -> bool");

extern "C" {static PyObject *meth_QComboBox_isEditable(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_isEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEditable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_isEditable, doc_QComboBox_isEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setEditable, "setEditable(self, editable: bool)");

extern "C" {static PyObject *meth_QComboBox_setEditable(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setEditable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setEditable, doc_QComboBox_setEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setLineEdit, "setLineEdit(self, edit: Optional[QLineEdit])");

extern "C" {static PyObject *meth_QComboBox_setLineEdit(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setLineEdit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLineEdit* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QLineEdit, &a0))
        {
            sipCpp->setLineEdit(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setLineEdit, doc_QComboBox_setLineEdit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_lineEdit, "lineEdit(self) -> Optional[QLineEdit]");

extern "C" {static PyObject *meth_QComboBox_lineEdit(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_lineEdit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QLineEdit*sipRes;

            sipRes = sipCpp->lineEdit();

            return sipConvertFromType(sipRes, sipType_QLineEdit, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_lineEdit, doc_QComboBox_lineEdit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setValidator, "setValidator(self, v: Optional[QValidator])");

extern "C" {static PyObject *meth_QComboBox_setValidator(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setValidator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QValidator* a0;
        PyObject *a0Keep;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QComboBox, &sipCpp, &a0Keep, sipType_QValidator, &a0))
        {
            sipCpp->setValidator(a0);

            sipKeepReference(sipSelf, -11, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setValidator, doc_QComboBox_setValidator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_validator, "validator(self) -> Optional[QValidator]");

extern "C" {static PyObject *meth_QComboBox_validator(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_validator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            const ::QValidator*sipRes;

            sipRes = sipCpp->validator();

            return sipConvertFromType(const_cast<::QValidator *>(sipRes), sipType_QValidator, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_validator, doc_QComboBox_validator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_itemDelegate, "itemDelegate(self) -> Optional[QAbstractItemDelegate]");

extern "C" {static PyObject *meth_QComboBox_itemDelegate(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_itemDelegate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QAbstractItemDelegate*sipRes;

            sipRes = sipCpp->itemDelegate();

            return sipConvertFromType(sipRes, sipType_QAbstractItemDelegate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_itemDelegate, doc_QComboBox_itemDelegate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setItemDelegate, "setItemDelegate(self, delegate: Optional[QAbstractItemDelegate])");

extern "C" {static PyObject *meth_QComboBox_setItemDelegate(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setItemDelegate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemDelegate* a0;
        PyObject *a0Keep;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QComboBox, &sipCpp, &a0Keep, sipType_QAbstractItemDelegate, &a0))
        {
            sipCpp->setItemDelegate(a0);

            sipKeepReference(sipSelf, -12, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setItemDelegate, doc_QComboBox_setItemDelegate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_model, "model(self) -> Optional[QAbstractItemModel]");

extern "C" {static PyObject *meth_QComboBox_model(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_model(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QAbstractItemModel*sipRes;

            sipRes = sipCpp->model();

            return sipConvertFromType(sipRes, sipType_QAbstractItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_model, doc_QComboBox_model);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setModel, "setModel(self, model: Optional[QAbstractItemModel])");

extern "C" {static PyObject *meth_QComboBox_setModel(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QComboBox, &sipCpp, &a0Keep, sipType_QAbstractItemModel, &a0))
        {
            sipCpp->setModel(a0);

            sipKeepReference(sipSelf, -13, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setModel, doc_QComboBox_setModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_rootModelIndex, "rootModelIndex(self) -> QModelIndex");

extern "C" {static PyObject *meth_QComboBox_rootModelIndex(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_rootModelIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->rootModelIndex());

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_rootModelIndex, doc_QComboBox_rootModelIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setRootModelIndex, "setRootModelIndex(self, index: QModelIndex)");

extern "C" {static PyObject *meth_QComboBox_setRootModelIndex(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setRootModelIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QModelIndex, &a0))
        {
            sipCpp->setRootModelIndex(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setRootModelIndex, doc_QComboBox_setRootModelIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_modelColumn, "modelColumn(self) -> int");

extern "C" {static PyObject *meth_QComboBox_modelColumn(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_modelColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->modelColumn();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_modelColumn, doc_QComboBox_modelColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setModelColumn, "setModelColumn(self, visibleColumn: int)");

extern "C" {static PyObject *meth_QComboBox_setModelColumn(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setModelColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setModelColumn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setModelColumn, doc_QComboBox_setModelColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_currentIndex, "currentIndex(self) -> int");

extern "C" {static PyObject *meth_QComboBox_currentIndex(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_currentIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_currentIndex, doc_QComboBox_currentIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setCurrentIndex, "setCurrentIndex(self, index: int)");

extern "C" {static PyObject *meth_QComboBox_setCurrentIndex(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setCurrentIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->setCurrentIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setCurrentIndex, doc_QComboBox_setCurrentIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_currentText, "currentText(self) -> str");

extern "C" {static PyObject *meth_QComboBox_currentText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_currentText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->currentText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_currentText, doc_QComboBox_currentText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_itemText, "itemText(self, index: int) -> str");

extern "C" {static PyObject *meth_QComboBox_itemText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_itemText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->itemText(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_itemText, doc_QComboBox_itemText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_itemIcon, "itemIcon(self, index: int) -> QIcon");

extern "C" {static PyObject *meth_QComboBox_itemIcon(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_itemIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(sipCpp->itemIcon(a0));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_itemIcon, doc_QComboBox_itemIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_itemData, "itemData(self, index: int, role: int = Qt.UserRole) -> Any");

extern "C" {static PyObject *meth_QComboBox_itemData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_itemData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = Qt::UserRole;
        const ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|i", &sipSelf, sipType_QComboBox, &sipCpp, &a0, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->itemData(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_itemData, doc_QComboBox_itemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_addItems, "addItems(self, texts: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QComboBox_addItems(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_addItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->addItems(*a0);
            sipReleaseType(const_cast<::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_addItems, doc_QComboBox_addItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_addItem, "addItem(self, text: Optional[str], userData: Any = None)\n"
"addItem(self, icon: QIcon, text: Optional[str], userData: Any = None)");

extern "C" {static PyObject *meth_QComboBox_addItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_addItem(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant& a1def = QVariant();
        const ::QVariant* a1 = &a1def;
        int a1State = 0;
        ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_userData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->addItem(*a0, *a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QIcon* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QVariant& a2def = QVariant();
        const ::QVariant* a2 = &a2def;
        int a2State = 0;
        ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_userData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|J1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QIcon, &a0, sipType_QString, &a1, &a1State, sipType_QVariant, &a2, &a2State))
        {
            sipCpp->addItem(*a0, *a1, *a2);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast<::QVariant *>(a2), sipType_QVariant, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_addItem, doc_QComboBox_addItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_insertItem, "insertItem(self, index: int, text: Optional[str], userData: Any = None)\n"
"insertItem(self, index: int, icon: QIcon, text: Optional[str], userData: Any = None)");

extern "C" {static PyObject *meth_QComboBox_insertItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_insertItem(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QVariant& a2def = QVariant();
        const ::QVariant* a2 = &a2def;
        int a2State = 0;
        ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_userData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ1|J1", &sipSelf, sipType_QComboBox, &sipCpp, &a0, sipType_QString, &a1, &a1State, sipType_QVariant, &a2, &a2State))
        {
            sipCpp->insertItem(a0, *a1, *a2);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast<::QVariant *>(a2), sipType_QVariant, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QIcon* a1;
        const ::QString* a2;
        int a2State = 0;
        const ::QVariant& a3def = QVariant();
        const ::QVariant* a3 = &a3def;
        int a3State = 0;
        ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_userData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ9J1|J1", &sipSelf, sipType_QComboBox, &sipCpp, &a0, sipType_QIcon, &a1, sipType_QString, &a2, &a2State, sipType_QVariant, &a3, &a3State))
        {
            sipCpp->insertItem(a0, *a1, *a2, *a3);
            sipReleaseType(const_cast<::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast<::QVariant *>(a3), sipType_QVariant, a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_insertItem, doc_QComboBox_insertItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_insertItems, "insertItems(self, index: int, texts: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QComboBox_insertItems(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_insertItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QStringList* a1;
        int a1State = 0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QComboBox, &sipCpp, &a0, sipType_QStringList, &a1, &a1State))
        {
            sipCpp->insertItems(a0, *a1);
            sipReleaseType(const_cast<::QStringList *>(a1), sipType_QStringList, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_insertItems, doc_QComboBox_insertItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_removeItem, "removeItem(self, index: int)");

extern "C" {static PyObject *meth_QComboBox_removeItem(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_removeItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->removeItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_removeItem, doc_QComboBox_removeItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setItemText, "setItemText(self, index: int, text: Optional[str])");

extern "C" {static PyObject *meth_QComboBox_setItemText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setItemText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QString* a1;
        int a1State = 0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QComboBox, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp->setItemText(a0, *a1);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setItemText, doc_QComboBox_setItemText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setItemIcon, "setItemIcon(self, index: int, icon: QIcon)");

extern "C" {static PyObject *meth_QComboBox_setItemIcon(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setItemIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QIcon* a1;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_QComboBox, &sipCpp, &a0, sipType_QIcon, &a1))
        {
            sipCpp->setItemIcon(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setItemIcon, doc_QComboBox_setItemIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setItemData, "setItemData(self, index: int, value: Any, role: int = Qt.ItemDataRole.UserRole)");

extern "C" {static PyObject *meth_QComboBox_setItemData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setItemData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QVariant* a1;
        int a1State = 0;
        int a2 = Qt::ItemDataRole::UserRole;
        ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ1|i", &sipSelf, sipType_QComboBox, &sipCpp, &a0, sipType_QVariant, &a1, &a1State, &a2))
        {
            sipCpp->setItemData(a0, *a1, a2);
            sipReleaseType(const_cast<::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setItemData, doc_QComboBox_setItemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_view, "view(self) -> Optional[QAbstractItemView]");

extern "C" {static PyObject *meth_QComboBox_view(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_view(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QAbstractItemView*sipRes;

            sipRes = sipCpp->view();

            return sipConvertFromType(sipRes, sipType_QAbstractItemView, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_view, doc_QComboBox_view);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setView, "setView(self, itemView: Optional[QAbstractItemView])");

extern "C" {static PyObject *meth_QComboBox_setView(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemView* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QAbstractItemView, &a0))
        {
            sipCpp->setView(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setView, doc_QComboBox_setView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QComboBox_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QComboBox::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_sizeHint, doc_QComboBox_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_minimumSizeHint, "minimumSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QComboBox_minimumSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_minimumSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QComboBox::minimumSizeHint() : sipCpp->minimumSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_minimumSizeHint, doc_QComboBox_minimumSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_showPopup, "showPopup(self)");

extern "C" {static PyObject *meth_QComboBox_showPopup(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_showPopup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::showPopup() : sipCpp->showPopup());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_showPopup, doc_QComboBox_showPopup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_hidePopup, "hidePopup(self)");

extern "C" {static PyObject *meth_QComboBox_hidePopup(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_hidePopup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::hidePopup() : sipCpp->hidePopup());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_hidePopup, doc_QComboBox_hidePopup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_event, "event(self, event: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QComboBox_event(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QComboBox::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_event, doc_QComboBox_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setCompleter, "setCompleter(self, c: Optional[QCompleter])");

extern "C" {static PyObject *meth_QComboBox_setCompleter(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setCompleter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCompleter* a0;
        PyObject *a0Keep;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QComboBox, &sipCpp, &a0Keep, sipType_QCompleter, &a0))
        {
            sipCpp->setCompleter(a0);

            sipKeepReference(sipSelf, -14, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setCompleter, doc_QComboBox_setCompleter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_completer, "completer(self) -> Optional[QCompleter]");

extern "C" {static PyObject *meth_QComboBox_completer(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_completer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QCompleter*sipRes;

            sipRes = sipCpp->completer();

            return sipConvertFromType(sipRes, sipType_QCompleter, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_completer, doc_QComboBox_completer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_insertSeparator, "insertSeparator(self, index: int)");

extern "C" {static PyObject *meth_QComboBox_insertSeparator(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_insertSeparator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            sipCpp->insertSeparator(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_insertSeparator, doc_QComboBox_insertSeparator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_clear, "clear(self)");

extern "C" {static PyObject *meth_QComboBox_clear(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_clear, doc_QComboBox_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_clearEditText, "clearEditText(self)");

extern "C" {static PyObject *meth_QComboBox_clearEditText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_clearEditText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            sipCpp->clearEditText();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_clearEditText, doc_QComboBox_clearEditText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setEditText, "setEditText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QComboBox_setEditText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setEditText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setEditText(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setEditText, doc_QComboBox_setEditText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setCurrentText, "setCurrentText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QComboBox_setCurrentText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setCurrentText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCurrentText(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setCurrentText, doc_QComboBox_setCurrentText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_initStyleOption, "initStyleOption(self, option: Optional[QStyleOptionComboBox])");

extern "C" {static PyObject *meth_QComboBox_initStyleOption(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_initStyleOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStyleOptionComboBox* a0;
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QStyleOptionComboBox, &a0))
        {
            sipCpp->initStyleOption(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_initStyleOption, doc_QComboBox_initStyleOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_focusInEvent, "focusInEvent(self, e: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QComboBox_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_focusInEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::focusInEvent(a0) : sipCpp->focusInEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_focusInEvent, doc_QComboBox_focusInEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_focusOutEvent, "focusOutEvent(self, e: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QComboBox_focusOutEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_focusOutEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::focusOutEvent(a0) : sipCpp->focusOutEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_focusOutEvent, doc_QComboBox_focusOutEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_changeEvent, "changeEvent(self, e: Optional[QEvent])");

extern "C" {static PyObject *meth_QComboBox_changeEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_changeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::changeEvent(a0) : sipCpp->changeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_changeEvent, doc_QComboBox_changeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_resizeEvent, "resizeEvent(self, e: Optional[QResizeEvent])");

extern "C" {static PyObject *meth_QComboBox_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_resizeEvent, doc_QComboBox_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_paintEvent, "paintEvent(self, e: Optional[QPaintEvent])");

extern "C" {static PyObject *meth_QComboBox_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_paintEvent, doc_QComboBox_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_showEvent, "showEvent(self, e: Optional[QShowEvent])");

extern "C" {static PyObject *meth_QComboBox_showEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_showEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QShowEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QShowEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::showEvent(a0) : sipCpp->showEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_showEvent, doc_QComboBox_showEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_hideEvent, "hideEvent(self, e: Optional[QHideEvent])");

extern "C" {static PyObject *meth_QComboBox_hideEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_hideEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QHideEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QHideEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::hideEvent(a0) : sipCpp->hideEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_hideEvent, doc_QComboBox_hideEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_mousePressEvent, "mousePressEvent(self, e: Optional[QMouseEvent])");

extern "C" {static PyObject *meth_QComboBox_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_mousePressEvent, doc_QComboBox_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_mouseReleaseEvent, "mouseReleaseEvent(self, e: Optional[QMouseEvent])");

extern "C" {static PyObject *meth_QComboBox_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_mouseReleaseEvent, doc_QComboBox_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_keyPressEvent, "keyPressEvent(self, e: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QComboBox_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_keyPressEvent, doc_QComboBox_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_keyReleaseEvent, "keyReleaseEvent(self, e: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QComboBox_keyReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_keyReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::keyReleaseEvent(a0) : sipCpp->keyReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_keyReleaseEvent, doc_QComboBox_keyReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_wheelEvent, "wheelEvent(self, e: Optional[QWheelEvent])");

extern "C" {static PyObject *meth_QComboBox_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_wheelEvent, doc_QComboBox_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_contextMenuEvent, "contextMenuEvent(self, e: Optional[QContextMenuEvent])");

extern "C" {static PyObject *meth_QComboBox_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QContextMenuEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_contextMenuEvent, doc_QComboBox_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_inputMethodEvent, "inputMethodEvent(self, a0: Optional[QInputMethodEvent])");

extern "C" {static PyObject *meth_QComboBox_inputMethodEvent(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_inputMethodEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QInputMethodEvent* a0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QInputMethodEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QComboBox::inputMethodEvent(a0) : sipCpp->inputMethodEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_inputMethodEvent, doc_QComboBox_inputMethodEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_inputMethodQuery, "inputMethodQuery(self, a0: Qt.InputMethodQuery) -> Any\n"
"inputMethodQuery(self, query: Qt.InputMethodQuery, argument: Any) -> Any");

extern "C" {static PyObject *meth_QComboBox_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::InputMethodQuery a0;
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QComboBox, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QComboBox::inputMethodQuery(a0) : sipCpp->inputMethodQuery(a0)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    {
        ::Qt::InputMethodQuery a0;
        const ::QVariant* a1;
        int a1State = 0;
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_Qt_InputMethodQuery, &a0, sipType_QVariant, &a1, &a1State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->inputMethodQuery(a0, *a1));
            sipReleaseType(const_cast<::QVariant *>(a1), sipType_QVariant, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_inputMethodQuery, doc_QComboBox_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_currentData, "currentData(self, role: int = Qt.ItemDataRole.UserRole) -> Any");

extern "C" {static PyObject *meth_QComboBox_currentData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QComboBox_currentData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = Qt::ItemDataRole::UserRole;
        const ::QComboBox *sipCpp;

        static const char *sipKwdList[] = {
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QComboBox, &sipCpp, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->currentData(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_currentData, doc_QComboBox_currentData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_setPlaceholderText, "setPlaceholderText(self, placeholderText: Optional[str])");

extern "C" {static PyObject *meth_QComboBox_setPlaceholderText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_setPlaceholderText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QComboBox, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPlaceholderText(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_setPlaceholderText, doc_QComboBox_setPlaceholderText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QComboBox_placeholderText, "placeholderText(self) -> str");

extern "C" {static PyObject *meth_QComboBox_placeholderText(PyObject *, PyObject *);}
static PyObject *meth_QComboBox_placeholderText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QComboBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QComboBox, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->placeholderText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QComboBox, sipName_placeholderText, doc_QComboBox_placeholderText);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QComboBox___len__(PyObject *);}
static Py_ssize_t slot_QComboBox___len__(PyObject *sipSelf)
{
    ::QComboBox *sipCpp = reinterpret_cast<::QComboBox *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QComboBox));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 3499 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQComboBox.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QComboBox(void *, const sipTypeDef *);}
static void *cast_QComboBox(void *sipCppV, const sipTypeDef *targetType)
{
    ::QComboBox *sipCpp = reinterpret_cast<::QComboBox *>(sipCppV);

    if (targetType == sipType_QComboBox)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast<::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QComboBox(void *, int);}
static void release_QComboBox(void *sipCppV, int)
{
    ::QComboBox *sipCpp = reinterpret_cast<::QComboBox *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QComboBox(Py_ssize_t);}
static void *array_QComboBox(Py_ssize_t sipNrElem)
{
    return new ::QComboBox[sipNrElem];
}


extern "C" {static void array_delete_QComboBox(void *);}
static void array_delete_QComboBox(void *sipCpp)
{
    delete[] reinterpret_cast<::QComboBox *>(sipCpp);
}


extern "C" {static void dealloc_QComboBox(sipSimpleWrapper *);}
static void dealloc_QComboBox(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQComboBox *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QComboBox(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QComboBox(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QComboBox(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQComboBox *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQComboBox(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QComboBox[] = {{463, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QComboBox[] = {
    {(void *)slot_QComboBox___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QComboBox[] = {
    {sipName_addItem, SIP_MLMETH_CAST(meth_QComboBox_addItem), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_addItem},
    {sipName_addItems, meth_QComboBox_addItems, METH_VARARGS, doc_QComboBox_addItems},
    {sipName_changeEvent, meth_QComboBox_changeEvent, METH_VARARGS, doc_QComboBox_changeEvent},
    {sipName_clear, meth_QComboBox_clear, METH_VARARGS, doc_QComboBox_clear},
    {sipName_clearEditText, meth_QComboBox_clearEditText, METH_VARARGS, doc_QComboBox_clearEditText},
    {sipName_completer, meth_QComboBox_completer, METH_VARARGS, doc_QComboBox_completer},
    {sipName_contextMenuEvent, meth_QComboBox_contextMenuEvent, METH_VARARGS, doc_QComboBox_contextMenuEvent},
    {sipName_count, meth_QComboBox_count, METH_VARARGS, doc_QComboBox_count},
    {sipName_currentData, SIP_MLMETH_CAST(meth_QComboBox_currentData), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_currentData},
    {sipName_currentIndex, meth_QComboBox_currentIndex, METH_VARARGS, doc_QComboBox_currentIndex},
    {sipName_currentText, meth_QComboBox_currentText, METH_VARARGS, doc_QComboBox_currentText},
    {sipName_duplicatesEnabled, meth_QComboBox_duplicatesEnabled, METH_VARARGS, doc_QComboBox_duplicatesEnabled},
    {sipName_event, meth_QComboBox_event, METH_VARARGS, doc_QComboBox_event},
    {sipName_findData, SIP_MLMETH_CAST(meth_QComboBox_findData), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_findData},
    {sipName_findText, SIP_MLMETH_CAST(meth_QComboBox_findText), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_findText},
    {sipName_focusInEvent, meth_QComboBox_focusInEvent, METH_VARARGS, doc_QComboBox_focusInEvent},
    {sipName_focusOutEvent, meth_QComboBox_focusOutEvent, METH_VARARGS, doc_QComboBox_focusOutEvent},
    {sipName_hasFrame, meth_QComboBox_hasFrame, METH_VARARGS, doc_QComboBox_hasFrame},
    {sipName_hideEvent, meth_QComboBox_hideEvent, METH_VARARGS, doc_QComboBox_hideEvent},
    {sipName_hidePopup, meth_QComboBox_hidePopup, METH_VARARGS, doc_QComboBox_hidePopup},
    {sipName_iconSize, meth_QComboBox_iconSize, METH_VARARGS, doc_QComboBox_iconSize},
    {sipName_initStyleOption, meth_QComboBox_initStyleOption, METH_VARARGS, doc_QComboBox_initStyleOption},
    {sipName_inputMethodEvent, meth_QComboBox_inputMethodEvent, METH_VARARGS, doc_QComboBox_inputMethodEvent},
    {sipName_inputMethodQuery, meth_QComboBox_inputMethodQuery, METH_VARARGS, doc_QComboBox_inputMethodQuery},
    {sipName_insertItem, SIP_MLMETH_CAST(meth_QComboBox_insertItem), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_insertItem},
    {sipName_insertItems, meth_QComboBox_insertItems, METH_VARARGS, doc_QComboBox_insertItems},
    {sipName_insertPolicy, meth_QComboBox_insertPolicy, METH_VARARGS, doc_QComboBox_insertPolicy},
    {sipName_insertSeparator, meth_QComboBox_insertSeparator, METH_VARARGS, doc_QComboBox_insertSeparator},
    {sipName_isEditable, meth_QComboBox_isEditable, METH_VARARGS, doc_QComboBox_isEditable},
    {sipName_itemData, SIP_MLMETH_CAST(meth_QComboBox_itemData), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_itemData},
    {sipName_itemDelegate, meth_QComboBox_itemDelegate, METH_VARARGS, doc_QComboBox_itemDelegate},
    {sipName_itemIcon, meth_QComboBox_itemIcon, METH_VARARGS, doc_QComboBox_itemIcon},
    {sipName_itemText, meth_QComboBox_itemText, METH_VARARGS, doc_QComboBox_itemText},
    {sipName_keyPressEvent, meth_QComboBox_keyPressEvent, METH_VARARGS, doc_QComboBox_keyPressEvent},
    {sipName_keyReleaseEvent, meth_QComboBox_keyReleaseEvent, METH_VARARGS, doc_QComboBox_keyReleaseEvent},
    {sipName_lineEdit, meth_QComboBox_lineEdit, METH_VARARGS, doc_QComboBox_lineEdit},
    {sipName_maxCount, meth_QComboBox_maxCount, METH_VARARGS, doc_QComboBox_maxCount},
    {sipName_maxVisibleItems, meth_QComboBox_maxVisibleItems, METH_VARARGS, doc_QComboBox_maxVisibleItems},
    {sipName_minimumContentsLength, meth_QComboBox_minimumContentsLength, METH_VARARGS, doc_QComboBox_minimumContentsLength},
    {sipName_minimumSizeHint, meth_QComboBox_minimumSizeHint, METH_VARARGS, doc_QComboBox_minimumSizeHint},
    {sipName_model, meth_QComboBox_model, METH_VARARGS, doc_QComboBox_model},
    {sipName_modelColumn, meth_QComboBox_modelColumn, METH_VARARGS, doc_QComboBox_modelColumn},
    {sipName_mousePressEvent, meth_QComboBox_mousePressEvent, METH_VARARGS, doc_QComboBox_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QComboBox_mouseReleaseEvent, METH_VARARGS, doc_QComboBox_mouseReleaseEvent},
    {sipName_paintEvent, meth_QComboBox_paintEvent, METH_VARARGS, doc_QComboBox_paintEvent},
    {sipName_placeholderText, meth_QComboBox_placeholderText, METH_VARARGS, doc_QComboBox_placeholderText},
    {sipName_removeItem, meth_QComboBox_removeItem, METH_VARARGS, doc_QComboBox_removeItem},
    {sipName_resizeEvent, meth_QComboBox_resizeEvent, METH_VARARGS, doc_QComboBox_resizeEvent},
    {sipName_rootModelIndex, meth_QComboBox_rootModelIndex, METH_VARARGS, doc_QComboBox_rootModelIndex},
    {sipName_setCompleter, meth_QComboBox_setCompleter, METH_VARARGS, doc_QComboBox_setCompleter},
    {sipName_setCurrentIndex, meth_QComboBox_setCurrentIndex, METH_VARARGS, doc_QComboBox_setCurrentIndex},
    {sipName_setCurrentText, meth_QComboBox_setCurrentText, METH_VARARGS, doc_QComboBox_setCurrentText},
    {sipName_setDuplicatesEnabled, meth_QComboBox_setDuplicatesEnabled, METH_VARARGS, doc_QComboBox_setDuplicatesEnabled},
    {sipName_setEditText, meth_QComboBox_setEditText, METH_VARARGS, doc_QComboBox_setEditText},
    {sipName_setEditable, meth_QComboBox_setEditable, METH_VARARGS, doc_QComboBox_setEditable},
    {sipName_setFrame, meth_QComboBox_setFrame, METH_VARARGS, doc_QComboBox_setFrame},
    {sipName_setIconSize, meth_QComboBox_setIconSize, METH_VARARGS, doc_QComboBox_setIconSize},
    {sipName_setInsertPolicy, meth_QComboBox_setInsertPolicy, METH_VARARGS, doc_QComboBox_setInsertPolicy},
    {sipName_setItemData, SIP_MLMETH_CAST(meth_QComboBox_setItemData), METH_VARARGS|METH_KEYWORDS, doc_QComboBox_setItemData},
    {sipName_setItemDelegate, meth_QComboBox_setItemDelegate, METH_VARARGS, doc_QComboBox_setItemDelegate},
    {sipName_setItemIcon, meth_QComboBox_setItemIcon, METH_VARARGS, doc_QComboBox_setItemIcon},
    {sipName_setItemText, meth_QComboBox_setItemText, METH_VARARGS, doc_QComboBox_setItemText},
    {sipName_setLineEdit, meth_QComboBox_setLineEdit, METH_VARARGS, doc_QComboBox_setLineEdit},
    {sipName_setMaxCount, meth_QComboBox_setMaxCount, METH_VARARGS, doc_QComboBox_setMaxCount},
    {sipName_setMaxVisibleItems, meth_QComboBox_setMaxVisibleItems, METH_VARARGS, doc_QComboBox_setMaxVisibleItems},
    {sipName_setMinimumContentsLength, meth_QComboBox_setMinimumContentsLength, METH_VARARGS, doc_QComboBox_setMinimumContentsLength},
    {sipName_setModel, meth_QComboBox_setModel, METH_VARARGS, doc_QComboBox_setModel},
    {sipName_setModelColumn, meth_QComboBox_setModelColumn, METH_VARARGS, doc_QComboBox_setModelColumn},
    {sipName_setPlaceholderText, meth_QComboBox_setPlaceholderText, METH_VARARGS, doc_QComboBox_setPlaceholderText},
    {sipName_setRootModelIndex, meth_QComboBox_setRootModelIndex, METH_VARARGS, doc_QComboBox_setRootModelIndex},
    {sipName_setSizeAdjustPolicy, meth_QComboBox_setSizeAdjustPolicy, METH_VARARGS, doc_QComboBox_setSizeAdjustPolicy},
    {sipName_setValidator, meth_QComboBox_setValidator, METH_VARARGS, doc_QComboBox_setValidator},
    {sipName_setView, meth_QComboBox_setView, METH_VARARGS, doc_QComboBox_setView},
    {sipName_showEvent, meth_QComboBox_showEvent, METH_VARARGS, doc_QComboBox_showEvent},
    {sipName_showPopup, meth_QComboBox_showPopup, METH_VARARGS, doc_QComboBox_showPopup},
    {sipName_sizeAdjustPolicy, meth_QComboBox_sizeAdjustPolicy, METH_VARARGS, doc_QComboBox_sizeAdjustPolicy},
    {sipName_sizeHint, meth_QComboBox_sizeHint, METH_VARARGS, doc_QComboBox_sizeHint},
    {sipName_validator, meth_QComboBox_validator, METH_VARARGS, doc_QComboBox_validator},
    {sipName_view, meth_QComboBox_view, METH_VARARGS, doc_QComboBox_view},
    {sipName_wheelEvent, meth_QComboBox_wheelEvent, METH_VARARGS, doc_QComboBox_wheelEvent}
};

static sipEnumMemberDef enummembers_QComboBox[] = {
    {sipName_AdjustToContents, static_cast<int>(::QComboBox::AdjustToContents), 48},
    {sipName_AdjustToContentsOnFirstShow, static_cast<int>(::QComboBox::AdjustToContentsOnFirstShow), 48},
    {sipName_AdjustToMinimumContentsLength, static_cast<int>(::QComboBox::AdjustToMinimumContentsLength), 48},
    {sipName_AdjustToMinimumContentsLengthWithIcon, static_cast<int>(::QComboBox::AdjustToMinimumContentsLengthWithIcon), 48},
    {sipName_InsertAfterCurrent, static_cast<int>(::QComboBox::InsertAfterCurrent), 47},
    {sipName_InsertAlphabetically, static_cast<int>(::QComboBox::InsertAlphabetically), 47},
    {sipName_InsertAtBottom, static_cast<int>(::QComboBox::InsertAtBottom), 47},
    {sipName_InsertAtCurrent, static_cast<int>(::QComboBox::InsertAtCurrent), 47},
    {sipName_InsertAtTop, static_cast<int>(::QComboBox::InsertAtTop), 47},
    {sipName_InsertBeforeCurrent, static_cast<int>(::QComboBox::InsertBeforeCurrent), 47},
    {sipName_NoInsert, static_cast<int>(::QComboBox::NoInsert), 47},
};

PyDoc_STRVAR(doc_QComboBox, "\1QComboBox(parent: Optional[QWidget] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QComboBox[] = {
    {"textHighlighted(QString)", "\1textHighlighted(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"textActivated(QString)", "\1textActivated(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"highlighted(int)", "\1highlighted(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"highlighted(QString)", "\1highlighted(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"currentTextChanged(QString)", "\1currentTextChanged(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"currentIndexChanged(int)", "\1currentIndexChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentIndexChanged(QString)", "\1currentIndexChanged(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"activated(int)", "\1activated(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"activated(QString)", "\1activated(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"editTextChanged(QString)", "\1editTextChanged(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QComboBox = {
    &::QComboBox::staticMetaObject,
    0,
    signals_QComboBox,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QComboBox = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QComboBox,
        SIP_NULLPTR,
        &plugin_QComboBox,
    },
    {
        sipNameNr_QComboBox,
        {0, 0, 1},
        80, methods_QComboBox,
        11, enummembers_QComboBox,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QComboBox,
    -1,
    -1,
    supers_QComboBox,
    slots_QComboBox,
    init_type_QComboBox,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QComboBox,
    SIP_NULLPTR,
    array_QComboBox,
    SIP_NULLPTR,
    release_QComboBox,
    cast_QComboBox,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QComboBox,
    sizeof (::QComboBox),
};
